==> dtlpy-1.92.19-py3-none-any.whl: dtlpy/entities/__init__.py <==
#! /usr/bin/env python3
# This file is part of DTLPY.
#
# DTLPY is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# DTLPY is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DTLPY.  If not, see <http://www.gnu.org/licenses/>.
from . import package_defaults
from .annotation_definitions import BaseAnnotationDefinition
from .base_entity import BaseEntity, DlEntity, DlProperty, DlList, EntityScopeLevel
from .item import Item, ItemStatus, Modality, ModalityTypeEnum, ModalityRefTypeEnum, ExportMetadata
from .links import Link, ItemLink, UrlLink, LinkTypeEnum
from .trigger import Trigger, TriggerResource, TriggerAction, TriggerExecutionMode, BaseTrigger, CronTrigger, \
    TriggerType
from .project import Project, MemberRole
from .artifact import ItemArtifact, LocalArtifact, LinkArtifact, ArtifactType, Artifact
from .dataset import Dataset, ExpirationOptions, IndexDriver, ExportType
from .codebase import Codebase
from .annotation import Annotation, FrameAnnotation, ViewAnnotationOptions, AnnotationStatus, AnnotationType, \
    ExportVersion
from .annotation_collection import AnnotationCollection
from .paged_entities import PagedEntities
from .filters import Filters, FiltersKnownFields, FiltersResource, FiltersOperations, FiltersMethod, \
    FiltersOrderByDirection
from .recipe import Recipe
from .ontology import Ontology, AttributesTypes, AttributesRange
from .annotation_definitions import Box, Cube, Cube3d, Point, Segmentation, Polygon, Ellipse, Classification, \
    Subtitle, Text, FreeText, RefImage, \
    Polyline, Comparison, UndefinedAnnotationType, Note, Message, Description, Pose
from .label import Label
from .codebase import Codebase, PackageCodebaseType, ItemCodebase, GitCodebase, FilesystemCodebase, LocalCodebase
from .package import Package, RequirementOperator, PackageRequirement
from .package_module import PackageModule
from .package_slot import PackageSlot, SlotPostAction, SlotPostActionType, SlotDisplayScope, SlotDisplayScopeResource, \
    UiBindingPanel
from .package_function import PackageFunction, FunctionIO, PackageInputType
from .time_series import TimeSeries
from .service import Service, KubernetesAutuscalerType, KubernetesRabbitmqAutoscaler, KubernetesAutoscaler, \
    InstanceCatalog, KubernetesRuntime, ServiceType, ServiceModeType
from .execution import Execution, ExecutionStatus
from .command import Command, CommandsStatus
from .assignment import Assignment, Workload, WorkloadUnit
from .task import Task, ItemAction, TaskPriority, ConsensusTaskType
from .directory_tree import DirectoryTree
from .user import User
from .bot import Bot
from .webhook import Webhook, HttpMethod
from .model import Model, DatasetSubsetType, PlotSample, ModelStatus
from .driver import Driver, S3Driver, GcsDriver, AzureBlobDriver
from .pipeline import Pipeline, PipelineStats, PipelineResumeOption, PipelineSettings, Variable, CompositionStatus
from .node import PipelineConnection, PipelineNode, PipelineConnectionPort, PipelineNodeIO, TaskNode, \
    CodeNode, FunctionNode, PipelineNodeType, PipelineNameSpace, DatasetNode
from .pipeline_execution import PipelineExecution, PipelineExecutionNode, CycleRerunMethod
from .feature import Feature
from .feature_set import FeatureSet, FeatureEntityType
from .organization import Organization, OrganizationsPlans, MemberOrgRole, CacheAction, PodType
from .analytic import ServiceSample, ExecutionSample, PipelineExecutionSample
from .integration import Integration, IntegrationType
from .driver import Driver, ExternalStorage
from .setting import Role, PlatformEntityType, SettingsValueTypes, SettingsTypes, SettingsSectionNames, SettingScope, \
    BaseSetting, UserSetting, Setting
from .reflect_dict import ReflectDict
from .dpk import Dpk, Panel, Toolbar, Components, DpkComputeConfig, DpkComponentChannel, PipelineNode, \
    CustomNodeScope, ToolbarInvoke
from .app import App, AppScope
from .app_module import AppModule
from .resource_execution import ResourceExecution
from .message import Message, NotificationEventContext
from .prompt_item import Prompt, PromptItem, PromptType

==> dtlpy-1.94.5-py3-none-any.whl: dtlpy/entities/__init__.py <==
#! /usr/bin/env python3
# This file is part of DTLPY.
#
# DTLPY is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# DTLPY is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DTLPY.  If not, see <http://www.gnu.org/licenses/>.
from . import package_defaults
from .annotation_definitions import BaseAnnotationDefinition
from .base_entity import BaseEntity, DlEntity, DlProperty, DlList, EntityScopeLevel
from .item import Item, ItemStatus, Modality, ModalityTypeEnum, ModalityRefTypeEnum, ExportMetadata
from .links import Link, ItemLink, UrlLink, LinkTypeEnum
from .trigger import Trigger, TriggerResource, TriggerAction, TriggerExecutionMode, BaseTrigger, CronTrigger, \
    TriggerType
from .project import Project, MemberRole
from .artifact import ItemArtifact, LocalArtifact, LinkArtifact, ArtifactType, Artifact
from .dataset import Dataset, ExpirationOptions, IndexDriver, ExportType
from .codebase import Codebase
from .annotation import Annotation, FrameAnnotation, ViewAnnotationOptions, AnnotationStatus, AnnotationType, \
    ExportVersion
from .annotation_collection import AnnotationCollection
from .paged_entities import PagedEntities
from .filters import Filters, FiltersKnownFields, FiltersResource, FiltersOperations, FiltersMethod, \
    FiltersOrderByDirection
from .recipe import Recipe
from .ontology import Ontology, AttributesTypes, AttributesRange
from .annotation_definitions import Box, Cube, Cube3d, Point, Segmentation, Polygon, Ellipse, Classification, \
    Subtitle, Text, FreeText, RefImage, \
    Polyline, Comparison, UndefinedAnnotationType, Note, Message, Description, Pose
from .label import Label
from .codebase import Codebase, PackageCodebaseType, ItemCodebase, GitCodebase, FilesystemCodebase, LocalCodebase
from .package import Package, RequirementOperator, PackageRequirement
from .package_module import PackageModule
from .package_slot import PackageSlot, SlotPostAction, SlotPostActionType, SlotDisplayScope, SlotDisplayScopeResource, \
    UiBindingPanel
from .package_function import PackageFunction, FunctionIO, PackageInputType
from .time_series import TimeSeries
from .service import Service, KubernetesAutuscalerType, KubernetesRabbitmqAutoscaler, KubernetesAutoscaler, \
    InstanceCatalog, KubernetesRuntime, ServiceType, ServiceModeType
from .execution import Execution, ExecutionStatus
from .command import Command, CommandsStatus
from .assignment import Assignment, Workload, WorkloadUnit
from .task import Task, ItemAction, TaskPriority, ConsensusTaskType
from .directory_tree import DirectoryTree
from .user import User
from .bot import Bot
from .webhook import Webhook, HttpMethod
from .model import Model, DatasetSubsetType, PlotSample, ModelStatus
from .driver import Driver, S3Driver, GcsDriver, AzureBlobDriver
from .pipeline import Pipeline, PipelineStats, PipelineResumeOption, PipelineSettings, Variable, CompositionStatus
from .node import PipelineConnection, PipelineNode, PipelineConnectionPort, PipelineNodeIO, TaskNode, \
    CodeNode, FunctionNode, PipelineNodeType, PipelineNameSpace, DatasetNode
from .pipeline_execution import PipelineExecution, PipelineExecutionNode, PipelineExecutionStatus, CycleRerunMethod
from .feature import Feature
from .feature_set import FeatureSet, FeatureEntityType
from .organization import Organization, OrganizationsPlans, MemberOrgRole, CacheAction, PodType
from .analytic import ServiceSample, ExecutionSample, PipelineExecutionSample
from .integration import Integration, IntegrationType
from .driver import Driver, ExternalStorage
from .setting import Role, PlatformEntityType, SettingsValueTypes, SettingsTypes, SettingsSectionNames, SettingScope, \
    BaseSetting, UserSetting, Setting
from .reflect_dict import ReflectDict
from .dpk import Dpk, Panel, Toolbar, Components, DpkComputeConfig, DpkComponentChannel, PipelineNode, \
    CustomNodeScope, ToolbarInvoke
from .app import App, AppScope
from .app_module import AppModule
from .resource_execution import ResourceExecution
from .message import Message, NotificationEventContext
from .prompt_item import Prompt, PromptItem, PromptType
from .compute import ClusterProvider, ComputeType, ComputeStatus, Toleration, DeploymentResource, DeploymentResources, \
    NodePool, AuthenticationIntegration, Authentication, ComputeCluster, ComputeContext, Compute, KubernetesCompute, \
    ServiceDriver
